@@ -692,12 +692,14 @@ def create_project(project_name):
     # Create tester files
     create_tester_file(project_name, directories['tester'], 'general_tester', False)
     create_tester_file(project_name, directories['tester'], 'evaluator', False)
+    create_empty_init_file(directories['tester'])
     create_schema_file(project_name, directories['test_schema'], 'test_input', False)
     create_schema_file(project_name, directories['test_schema'], 'test_output', False)
-
+    create_empty_init_file(directories['test_schema'])
     create_dsp_file(original_project_name, directories['dsp'], 'get_model_options', False)
     create_dsp_file(original_project_name, directories['dsp'], 'get_dataset_options', False)
     create_dsp_file(original_project_name, directories['dsp'], 'add_experiment', False)
+    create_empty_init_file(directories['dsp'])
 
     # Create trainer files
     create_trainer_file(project_name, directories['pl_wrapper'], 'custom_dataset', False, from_folder='pl_wrapper')
@@ -705,6 +707,7 @@ def create_project(project_name):
     create_trainer_file(project_name, directories['pl_wrapper'], 'iterable_dataset', False, from_folder='pl_wrapper')
     create_trainer_file(project_name, directories['pl_wrapper'], 'plmodel', False, from_folder='pl_wrapper')
     create_trainer_file(project_name, directories['pl_wrapper'], 'network_module', False, from_folder='pl_wrapper')
+    create_empty_init_file(directories['pl_wrapper'])
     create_trainer_file(project_name, directories['trainer'], 'comparison', False)
     create_trainer_file(project_name, directories['trainer'], 'config', False)
     create_trainer_file(project_name, directories['trainer'], 'data', False)
@@ -713,6 +716,7 @@ def create_project(project_name):
     create_trainer_file(project_name, directories['trainer'], 'test', False)
     create_trainer_file(project_name, directories['trainer'], 'train', False)
     create_trainer_file(project_name, directories['trainer'], 'main', False)
+    create_empty_init_file(directories['trainer'])
     source_path = os.path.join(__location__, 'dsframework/cli/trainer/requirements_trainer.txt')
     shutil.copyfile(source_path, directories['trainer'] + '/requirements_trainer.txt')
 
@@ -980,6 +984,16 @@ def replace_in_template_and_create_file(project_name, folder, pipelineType, data
         create_init_file(new_init_file, new_init_export)
 
 
+def create_empty_init_file(folder):
+    """Creates an empty __init__.py file
+    Args:
+        folder       : The folder we want to create the new file in.
+    """
+
+    new_init_file = folder + "/__init__.py"
+    create_init_file(new_init_file, '')
+
+
 def create_predictable_file(fileName):
     pass
 
