@@ -21,18 +21,16 @@ from google.cloud.dataproc_v1.types.workflow_templates import WorkflowTemplate
 # @file
 # @brief Defines workflow base class.
 class ZIDS_Workflow():
-    def __init__(self, pip_packages):
+    def __init__(self):
         """! ZIDS_Workflow initializer.
-        Loads config file and initializes parameters.
+        Loads config file and initializes parameters."""
 
-            Args:
-                 pip_packages: A list of pip packages read from requirements file.
-        """
+        self.trainer = False
 
         file_path = sys.modules[self.__class__.__module__].__file__
-        curr_path = file_path[:file_path.rfind("batch_files")]
+        self.curr_path = file_path[:file_path.rfind("batch_files")]
 
-        with open(curr_path + '/batch_files/batch_config.json') as batch_cfg_file:
+        with open(self.curr_path + 'batch_files/batch_config.json') as batch_cfg_file:
             self.config = json_load(batch_cfg_file)
 
         self.user_email = ''
@@ -71,9 +69,6 @@ class ZIDS_Workflow():
                                                                             region=self.region)
 
         if self.config['cluster_conf']['managed_cluster']:
-            # Configure pip packages
-            self.config['cluster_conf']['managed_cluster']['config']['gce_cluster_config']['metadata']['PIP_PACKAGES'] \
-                = pip_packages
 
             # Configure initialization script
             cluster_init_action = {"executable_file": f"{self.bucket_path}"
@@ -93,6 +88,36 @@ class ZIDS_Workflow():
         # Define extra stage parameters
         self.extra_params = json_dumps(self.config['extra_job_params'])
 
+    def set_trainer_mode(self, mode: bool = False):
+        """Define trainer mode, sets the self.trainer.
+        Currently, used in the export_template_structure() to determine which stages to use."""
+        self.trainer = mode
+
+    def configure_pip_packages(self, requirements_path: str, append: bool = False):
+        """Configure pip packages based on the required steps.
+
+        Args:
+            requirements_path: Path to requirements.txt file.
+            append: Append requirement packages to the currently loaded ones.
+
+        """
+
+        with open(requirements_path) as req_file:
+            required_pkg = req_file.read().splitlines()
+            required_pkg = [x for x in required_pkg if "#" not in x]
+            pip_packages = ' '.join(required_pkg)
+
+        if self.config['cluster_conf']['managed_cluster']:
+            # Configure pip packages
+            if not append:
+                self.config['cluster_conf']['managed_cluster']['config']['gce_cluster_config']['metadata'][
+                    'PIP_PACKAGES'] \
+                    = pip_packages
+            else:
+                self.config['cluster_conf']['managed_cluster']['config']['gce_cluster_config']['metadata'][
+                    'PIP_PACKAGES'] \
+                    += ' ' + pip_packages
+
     def check_cluster(self):
         """! ZIDS_Workflow get_cluster.
         Tries to locate existing cluster that should be set up by this point.
@@ -137,7 +162,8 @@ class ZIDS_Workflow():
         template.placement = cluster_config
         return template
 
-    def create_ordered_job(self, stage_dir: str, spark_properties, python_files, archive_files) -> OrderedJob:
+    def create_ordered_job(self, stage_dir: str, spark_properties, python_files, archive_files,
+                           additional_args=[], additional_jars=[]) -> OrderedJob:
         """! ZIDS_Workflow create_ordered_job.
         Create an ordered job from a stage directory
 
@@ -147,6 +173,8 @@ class ZIDS_Workflow():
                 spark_properties: A list, containing different spark properties
                 python_files: A list of files which hold the project code (Can be archived)
                 archive_files: A list of compressed files that the stage requires
+                additional_args: A list of additional arguments, to add on top of the default ones
+                additional_jars: A list of additional jar files, to add on top of the default ones
             Returns:
                 An ordered job
         """
@@ -162,8 +190,8 @@ class ZIDS_Workflow():
         pyJob.python_file_uris = [f'{self.bucket_path}/dist/{file_name}' if file_name.find('gs:') == -1
                                   else file_name for file_name in python_files]
         pyJob.properties = spark_properties
-        pyJob.args = self.default_args + []
-        pyJob.jar_file_uris = self.default_jars + []
+        pyJob.args = self.default_args + additional_args
+        pyJob.jar_file_uris = self.default_jars + additional_jars
         created_stage.step_id = f'{self.project_name}-stage_{stage_name}'
         created_stage.pyspark_job = pyJob
         return created_stage
