@@ -1,5 +1,5 @@
 import sys
-from typing import List
+from typing import List, Any
 
 import pandas as pd
 import os
@@ -182,21 +182,21 @@ class generatedClass(ZIDS_Tester):
         self.run_test(df, batch_size)
 
     def test_from_dataset(self, dataset, batch_size):
-        """! Run an evaluation from a csv file input.
+        """! Run an evaluation on a given dataset.
 
         Args:
-            csv_file_path: csv file containing both ground truth and raw input for the model.
+            dataset: a file containing both ground truth and raw input for the model.
             batch_size: Size of batch to use in order to feed the model with controllable chunks of data
         """
-        df = dataset
+        df = self.convert_to_dataframe(dataset)  # convert dataset to dataframe.
         csv_output_path = self.run_test(df, batch_size)
         return csv_output_path
 
     def run_test(self, df, batch_size):
-        """! Run an evaluation from a csv file input.
+        """! Run an evaluation from a given DataFrame input.
 
         Args:
-            csv_file_path: csv file containing both ground truth and raw input for the model.
+            df: Dataframe
             batch_size: Size of batch to use in order to feed the model with controllable chunks of data
         """
         # Define csv output
@@ -236,6 +236,19 @@ class generatedClass(ZIDS_Tester):
 
         return csv_output_path
 
+    def convert_to_dataframe(self, dataset_test: Any) -> pd.DataFrame:
+        """ Conversion of test dataset to Pandas dataframe, to run evaluation process.
+
+        Not implemented.
+
+        Args:
+            dataset_test: Input dataset, Any type.
+
+        Returns:
+            Convert dataset to pd.Dataframe.
+        """
+        pass
+
 # This will call the tester with a given csv file
 if __name__ == '__main__':
 
